<?php

/**
 * @copyright Copyright 2006-2022 Bigmouse, Inc
 * @version $Id$: class.jp_format.php 1 2022-10-25 09:38 bigmouse-inada $
 **/

class jp_format extends base
{

    function __construct()
    {
        $this->attach($this, array(
            'NOTIFY_MODULE_CREATE_ACCOUNT_ADDED_CUSTOMER_RECORD',
            'NOTIFY_MODULE_CREATE_ACCOUNT_ADDED_ADDRESS_BOOK_RECORD',
            'NOTIFY_HEADER_ACCOUNT_EDIT_UPDATES_COMPLETE',
            'NOTIFY_ADDRESS_BOOK_PROCESS_VALIDATION',
            'NOTIFY_MODULE_ADDRESS_BOOK_UPDATED_ADDRESS_BOOK_RECORD',
            'NOTIFY_MODULE_ADDRESS_BOOK_ADDED_ADDRESS_BOOK_RECORD',
            'NOTIFY_CREATE_ACCOUNT_VALIDATION_CHECK',
            'NOTIFY_MODULE_CHECKOUT_NEW_ADDRESS_VALIDATION',
            'NOTIFY_MODULE_CHECKOUT_ADDED_ADDRESS_BOOK_RECORD',
            'NOTIFY_ORDER_DURING_CREATE_ADDED_ORDER_HEADER',
            'NOTIFY_HEADER_END_ACCOUNT_HISTORY_INFO',
            'NOTIFY_CHECKOUT_PROCESS_AFTER_ORDER_CREATE_ADD_PRODUCTS',
            'NOTIFY_CHECKOUT_PROCESS_AFTER_SEND_ORDER_EMAIL'
        ));
    }

    function update(&$class, $eventID, $paramsArray = array())
    {
        global $messageStack, $db;
        if ($eventID == 'NOTIFY_MODULE_CREATE_ACCOUNT_ADDED_CUSTOMER_RECORD') {
            if (isset($_POST['firstname_kana'])) {
                $firstname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['firstname_kana']));
                $lastname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['lastname_kana']));
                $where_clause = "customers_id = :customersID";
                $where_clause = $db->bindVars($where_clause, ':customersID', $paramsArray['customer_id'], 'integer');
                $sql_data_array = array(
                    array('fieldName' => 'customers_firstname_kana', 'value' => $firstname_kana, 'type' => 'stringIgnoreNull'),
                    array('fieldName' => 'customers_lastname_kana', 'value' => $lastname_kana, 'type' => 'stringIgnoreNull')
                );
                $db->perform(TABLE_CUSTOMERS, $sql_data_array, 'update', $where_clause);
            }
        } elseif ($eventID == 'NOTIFY_MODULE_CREATE_ACCOUNT_ADDED_ADDRESS_BOOK_RECORD') {
            global $data;
            if (!isset($_POST['firstname_kana'])) $_POST['firstname_kana'] = '';
            if (!isset($_POST['lastname_kana'])) $_POST['lastname_kana'] = '';
            $firstname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['firstname_kana']));
            $lastname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['lastname_kana']));
            $sql_data_array = array(
                array('fieldName' => 'entry_firstname_kana', 'value' => $firstname_kana, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_lastname_kana', 'value' => $lastname_kana, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_telephone', 'value' => $data['telephone'], 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_fax', 'value' => $data['fax'], 'type' => 'stringIgnoreNull')
            );
            $db->perform(TABLE_ADDRESS_BOOK, $sql_data_array, 'update', "address_book_id = '" . $paramsArray['address_id'] . "'");
        } elseif ($eventID == 'NOTIFY_HEADER_ACCOUNT_EDIT_UPDATES_COMPLETE') {
            global $telephone, $fax;
            $where_clause = "customers_id = :customersID AND address_book_id = :customerDefaultAddressID";
            $where_clause = $db->bindVars($where_clause, ':customersID', $_SESSION['customer_id'], 'integer');
            $where_clause = $db->bindVars($where_clause, ':customerDefaultAddressID', $_SESSION['customer_default_address_id'], 'integer');
            $sql_data_array = array(
                array('fieldName' => 'entry_telephone', 'value' => $telephone, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_fax', 'value' => $fax, 'type' => 'stringIgnoreNull')
            );
            $db->perform(TABLE_ADDRESS_BOOK, $sql_data_array, 'update', $where_clause);
        } elseif ($eventID == 'NOTIFY_ADDRESS_BOOK_PROCESS_VALIDATION') {
            if (zen_add_furigana()) {
                global $error;
                if (!isset($_POST['firstname_kana'])) $_POST['firstname_kana'] = '';
                if (!isset($_POST['lastname_kana'])) $_POST['lastname_kana'] = '';
                $firstname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['firstname_kana']));
                $lastname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['lastname_kana']));
                if (strlen($firstname_kana) < ENTRY_FIRST_NAME_MIN_LENGTH) {
                    $error = true;
                    $messageStack->add('addressbook', ENTRY_FIRST_NAME_KANA_ERROR);
                }
                if (strlen($lastname_kana) < ENTRY_LAST_NAME_MIN_LENGTH) {
                    $error = true;
                    $messageStack->add('addressbook', ENTRY_LAST_NAME_KANA_ERROR);
                }
            }
            $entry_telephone = zen_db_prepare_input($_POST['entry_telephone']);
            if (strlen($entry_telephone) < ENTRY_TELEPHONE_MIN_LENGTH) {
                $error = true;
                $messageStack->add('create_account', ENTRY_TELEPHONE_NUMBER_ERROR);
            }
        } elseif ($eventID == 'NOTIFY_MODULE_ADDRESS_BOOK_UPDATED_ADDRESS_BOOK_RECORD') {
            if (!isset($_POST['firstname_kana'])) $_POST['firstname_kana'] = '';
            if (!isset($_POST['lastname_kana'])) $_POST['lastname_kana'] = '';
            $firstname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['firstname_kana']));
            $lastname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['lastname_kana']));
            $entry_telephone = zen_db_prepare_input($_POST['entry_telephone']);
            $entry_fax = zen_db_prepare_input($_POST['entry_fax']);
            $where_clause = "customers_id = :customersID AND address_book_id = :address_book_id";
            $where_clause = $db->bindVars($where_clause, ':customersID', $_SESSION['customer_id'], 'integer');
            $where_clause = $db->bindVars($where_clause, ':address_book_id', $paramsArray['address_book_id'], 'integer');
            $sql_data_array = array(
                array('fieldName' => 'entry_firstname_kana', 'value' => $firstname_kana, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_lastname_kana', 'value' => $lastname_kana, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_telephone', 'value' => $entry_telephone, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_fax', 'value' => $entry_fax, 'type' => 'stringIgnoreNull')
            );
            $db->perform(TABLE_ADDRESS_BOOK, $sql_data_array, 'update', $where_clause);
            if ((isset($_POST['primary']) && ($_POST['primary'] == 'on')) || ($_GET['edit'] == $_SESSION['customer_default_address_id'])) {
                $where_clause = "customers_id = :customersID";
                $where_clause = $db->bindVars($where_clause, ':customersID', $_SESSION['customer_id'], 'integer');
                $sql_data_array = array(
                    array('fieldName' => 'customers_firstname_kana', 'value' => $firstname_kana, 'type' => 'stringIgnoreNull'),
                    array('fieldName' => 'customers_lastname_kana', 'value' => $lastname_kana, 'type' => 'stringIgnoreNull'),
                    array('fieldName' => 'customers_telephone', 'value' => $entry_telephone, 'type' => 'stringIgnoreNull'),
                    array('fieldName' => 'customers_fax', 'value' => $entry_fax, 'type' => 'stringIgnoreNull')
                );
                $db->perform(TABLE_CUSTOMERS, $sql_data_array, 'update', $where_clause);
            }
        } elseif ($eventID == 'NOTIFY_MODULE_ADDRESS_BOOK_ADDED_ADDRESS_BOOK_RECORD') {
            $firstname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['firstname_kana']));
            $lastname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['lastname_kana']));
            $entry_telephone = zen_db_prepare_input($_POST['entry_telephone']);
            $entry_fax = zen_db_prepare_input($_POST['entry_fax']);
            $where_clause = "customers_id = :customersID AND address_book_id = :address_book_id";
            $where_clause = $db->bindVars($where_clause, ':customersID', $_SESSION['customer_id'], 'integer');
            $where_clause = $db->bindVars($where_clause, ':address_book_id', $paramsArray['address_id'], 'integer');
            $sql_data_array = array(
                array('fieldName' => 'entry_firstname_kana', 'value' => $firstname_kana, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_lastname_kana', 'value' => $lastname_kana, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_telephone', 'value' => $entry_telephone, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_fax', 'value' => $entry_fax, 'type' => 'stringIgnoreNull')
            );
            $db->perform(TABLE_ADDRESS_BOOK, $sql_data_array, 'update', $where_clause);
            if (isset($_POST['primary']) && ($_POST['primary'] == 'on')) {
                $where_clause = "customers_id = :customersID";
                $where_clause = $db->bindVars($where_clause, ':customersID', $_SESSION['customer_id'], 'integer');
                $sql_data_array = array(
                    array('fieldName' => 'customers_firstname_kana', 'value' => $firstname_kana, 'type' => 'stringIgnoreNull'),
                    array('fieldName' => 'customers_lastname_kana', 'value' => $lastname_kana, 'type' => 'stringIgnoreNull'),
                    array('fieldName' => 'customers_telephone', 'value' => $entry_telephone, 'type' => 'stringIgnoreNull'),
                    array('fieldName' => 'customers_fax', 'value' => $entry_fax, 'type' => 'stringIgnoreNull')
                );
                $db->perform(TABLE_CUSTOMERS, $sql_data_array, 'update', $where_clause);
            }
        } elseif ($eventID == 'NOTIFY_CREATE_ACCOUNT_VALIDATION_CHECK') {
            if (zen_add_furigana()) {
                global $error;
                if (!isset($_POST['firstname_kana'])) $_POST['firstname_kana'] = '';
                if (!isset($_POST['lastname_kana'])) $_POST['lastname_kana'] = '';
                $firstname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['firstname_kana']));
                $lastname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['lastname_kana']));
                if (strlen($firstname_kana) < ENTRY_FIRST_NAME_MIN_LENGTH) {
                    $error = true;
                    $messageStack->add('create_account', ENTRY_FIRST_NAME_KANA_ERROR);
                }
                if (strlen($lastname_kana) < ENTRY_LAST_NAME_MIN_LENGTH) {
                    $error = true;
                    $messageStack->add('create_account', ENTRY_LAST_NAME_KANA_ERROR);
                }
            }
        } elseif ($eventID == 'NOTIFY_MODULE_CHECKOUT_NEW_ADDRESS_VALIDATION') {
            if (zen_add_furigana()) {
                if (!isset($_POST['firstname_kana'])) $_POST['firstname_kana'] = '';
                if (!isset($_POST['lastname_kana'])) $_POST['lastname_kana'] = '';
                global $error, $firstname_kana, $lastname_kana, $telephone;
                $firstname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['firstname_kana']));
                $lastname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['lastname_kana']));
                if (strlen($firstname_kana) < ENTRY_FIRST_NAME_MIN_LENGTH) {
                    $error = true;
                    $messageStack->add('checkout_address', ENTRY_FIRST_NAME_KANA_ERROR);
                }
                if (strlen($lastname_kana) < ENTRY_LAST_NAME_MIN_LENGTH) {
                    $error = true;
                    $messageStack->add('checkout_address', ENTRY_LAST_NAME_KANA_ERROR);
                }
            }
            $telephone = zen_db_prepare_input($_POST['telephone']);
            $fax = zen_db_prepare_input($_POST['fax']);
            if (strlen($telephone) < ENTRY_TELEPHONE_MIN_LENGTH) {
                $error = true;
                $messageStack->add('checkout_address', ENTRY_TELEPHONE_NUMBER_ERROR);
            }
        } elseif ($eventID == 'NOTIFY_MODULE_CHECKOUT_ADDED_ADDRESS_BOOK_RECORD') {

            if (!isset($_POST['firstname_kana'])) $_POST['firstname_kana'] = '';
            if (!isset($_POST['lastname_kana'])) $_POST['lastname_kana'] = '';
            $firstname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['firstname_kana']));
            $lastname_kana = zen_db_prepare_input(zen_sanitize_string($_POST['lastname_kana']));
            $telephone = zen_db_prepare_input($_POST['telephone']);
            $fax = zen_db_prepare_input($_POST['fax']);
            $sql_data_array = array(
                array('fieldName' => 'entry_firstname_kana', 'value' => $firstname_kana, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_lastname_kana', 'value' => $lastname_kana, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_telephone', 'value' => $telephone, 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'entry_fax', 'value' => $fax, 'type' => 'stringIgnoreNull')
            );
            $db->perform(TABLE_ADDRESS_BOOK, $sql_data_array, 'update', "address_book_id = '" . (int)$paramsArray['address_id'] . "'");
        } elseif ($eventID == 'NOTIFY_ORDER_DURING_CREATE_ADDED_ORDER_HEADER') {
            global $order;
            $sendto = (!empty($_SESSION['sendto']) ? (int)$_SESSION['sendto'] : (int)$_SESSION['customer_default_address_id']);
            $billto = (!empty($_SESSION['billto']) ? (int)$_SESSION['billto'] : (int)$_SESSION['customer_default_address_id']);
            $customer_address_query = "SELECT entry_telephone, entry_fax, entry_firstname_kana, entry_lastname_kana
                                       FROM " . TABLE_ADDRESS_BOOK . "
                                       WHERE customers_id = " . (!empty($_SESSION['customer_id']) ? (int)$_SESSION['customer_id'] : 0) . "
                                       AND address_book_id = '" . (int)$_SESSION['customer_default_address_id'] . "'";
            $customer_address = $db->Execute($customer_address_query);

            if ($_SESSION['customer_default_address_id'] != $sendto) {
                $shipping_address_query = "SELECT entry_telephone, entry_fax, entry_firstname_kana, entry_lastname_kana
                                           FROM " . TABLE_ADDRESS_BOOK . "
                                           WHERE customers_id = " . (!empty($_SESSION['customer_id']) ? (int)$_SESSION['customer_id'] : 0) . "
                                           AND address_book_id = " . $sendto;
                $shipping_address = $db->Execute($shipping_address_query);
            } else {
                $shipping_address = $customer_address;
            }

            if ($_SESSION['customer_default_address_id'] != $billto) {
                $billing_address_query = "SELECT entry_telephone, entry_fax, entry_firstname_kana, entry_lastname_kana
                                           FROM " . TABLE_ADDRESS_BOOK . "
                                           WHERE customers_id = " . (!empty($_SESSION['customer_id']) ? (int)$_SESSION['customer_id'] : 0) . "
                                           AND address_book_id = " . $billto;
                $billing_address = $db->Execute($billing_address_query);
            } else {
                $billing_address = $customer_address;
            }
            $sql_data_array = array(
                array('fieldName' => 'customers_fax', 'value' => $customer_address->fields['entry_fax'], 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'customers_name_kana', 'value' => $customer_address->fields['entry_firstname_kana'] . ' ' . $customer_address->fields['entry_lastname_kana'], 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'delivery_telephone', 'value' => $shipping_address->fields['entry_telephone'], 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'delivery_fax', 'value' => $shipping_address->fields['entry_fax'], 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'delivery_name_kana', 'value' => $shipping_address->fields['entry_firstname_kana'] . ' ' . $shipping_address->fields['entry_lastname_kana'], 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'billing_telephone', 'value' => $billing_address->fields['entry_telephone'], 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'billing_fax', 'value' => $billing_address->fields['entry_fax'], 'type' => 'stringIgnoreNull'),
                array('fieldName' => 'billing_name_kana', 'value' => $billing_address->fields['entry_firstname_kana'] . ' ' . $billing_address->fields['entry_lastname_kana'], 'type' => 'stringIgnoreNull')
            );
            $db->perform(TABLE_ORDERS, $sql_data_array, 'update', "orders_id = '" . (int)$paramsArray['orders_id'] . "'");
        } elseif ($eventID == 'NOTIFY_HEADER_END_ACCOUNT_HISTORY_INFO') {
            global $order;
            $sql = $db->Execute("SELECT delivery_telephone, delivery_fax, billing_telephone, billing_fax, customers_fax, customers_name_kana, delivery_name_kana, billing_name_kana FROM " . TABLE_ORDERS . " WHERE orders_id = '" . (int)$_GET['order_id'] . "'");
            $order->customer['name_kana'] = $sql->fields['customers_name_kana'];
            $order->customer['fax'] = $sql->fields['customers_fax'];
            $order->delivery['name_kana'] = $sql->fields['delivery_name_kana'];
            $order->delivery['telephone'] = $sql->fields['delivery_telephone'];
            $order->delivery['fax'] = $sql->fields['delivery_fax'];
            $order->billing['name_kana'] = $sql->fields['billing_name_kana'];
            $order->billing['telephone'] = $sql->fields['billing_telephone'];
            $order->billing['fax'] = $sql->fields['billing_fax'];
        } elseif ($eventID == 'NOTIFY_CHECKOUT_PROCESS_AFTER_ORDER_CREATE_ADD_PRODUCTS') {
            global $order, $customer_lastname;
            $customer_lastname = $order->customer['lastname'];
            $order->customer['lastname'] .= ADDRESSFORMAT_EMAIL_GREET;
        } elseif ($eventID == 'NOTIFY_CHECKOUT_PROCESS_AFTER_SEND_ORDER_EMAIL') {
            global $order, $customer_lastname;
            $order->customer['lastname'] = $customer_lastname;
        }
    }
}
